@@ -56,7 +56,7 @@ create_thumbnail_frame (int        width,
 	}
 
 	/* make sure no one is passing us garbage */
-	g_assert (width_r >= 0 && height_r >= 0);
+	g_return_val_if_fail (width_r >= 0 && height_r >= 0, NULL);
 
 	retval = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
 				 TRUE, 8,
@@ -180,6 +180,8 @@ ev_document_misc_surface_from_pixbuf (GdkPixbuf *pixbuf)
 	cairo_surface_t *surface;
 	cairo_t         *cr;
 
+	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
+
 	surface = cairo_image_surface_create (gdk_pixbuf_get_has_alpha (pixbuf) ?
 					      CAIRO_FORMAT_ARGB32 : CAIRO_FORMAT_RGB24,
 					      gdk_pixbuf_get_width (pixbuf),
@@ -195,68 +197,12 @@ ev_document_misc_surface_from_pixbuf (GdkPixbuf *pixbuf)
 GdkPixbuf *
 ev_document_misc_pixbuf_from_surface (cairo_surface_t *surface)
 {
-	GdkPixbuf       *pixbuf;
-	cairo_surface_t *image;
-	cairo_t         *cr;
-	gboolean         has_alpha;
-	gint             width, height;
-	cairo_format_t   surface_format;
-	gint             pixbuf_n_channels;
-	gint             pixbuf_rowstride;
-	guchar          *pixbuf_pixels;
-	gint             x, y;
+	g_return_val_if_fail (surface, NULL);	
 
-	width = cairo_image_surface_get_width (surface);
-	height = cairo_image_surface_get_height (surface);
-	
-	surface_format = cairo_image_surface_get_format (surface);
-	has_alpha = (surface_format == CAIRO_FORMAT_ARGB32);
-
-	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-				 TRUE, 8,
-				 width, height);
-	pixbuf_n_channels = gdk_pixbuf_get_n_channels (pixbuf);
-	pixbuf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-	pixbuf_pixels = gdk_pixbuf_get_pixels (pixbuf);
-
-	image = cairo_image_surface_create_for_data (pixbuf_pixels,
-						     surface_format,
-						     width, height,
-						     pixbuf_rowstride);
-	cr = cairo_create (image);
-	cairo_set_source_surface (cr, surface, 0, 0);
-
-	if (has_alpha)
-		cairo_mask_surface (cr, surface, 0, 0);
-	else
-		cairo_paint (cr);
-
-	cairo_destroy (cr);
-	cairo_surface_destroy (image);
-
-	for (y = 0; y < height; y++) {
-		guchar *p = pixbuf_pixels + y * pixbuf_rowstride;
-
-		for (x = 0; x < width; x++) {
-			guchar tmp;
-			
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-			tmp = p[0];
-			p[0] = p[2];
-			p[2] = tmp;
-			p[3] = (has_alpha) ? p[3] : 0xff;
-#else
-			tmp = p[0];
-			p[0] = p[1];
-			p[1] = p[2];
-			p[2] = p[3];
-			p[3] = (has_alpha) ? tmp : 0xff;
-#endif			
-			p += pixbuf_n_channels;
-		}
-	}
-
-	return pixbuf;
+        return gdk_pixbuf_get_from_surface (surface,
+                                            0, 0,
+                                            cairo_image_surface_get_width (surface),
+                                            cairo_image_surface_get_height (surface));
 }
 
 cairo_surface_t *
@@ -321,7 +267,6 @@ ev_document_misc_surface_rotate_and_scale (cairo_surface_t *surface,
 
 void
 ev_document_misc_invert_surface (cairo_surface_t *surface) {
-#if CAIRO_VERSION > CAIRO_VERSION_ENCODE(1, 9, 2)
 	cairo_t *cr;
 
 	cr = cairo_create (surface);
@@ -331,30 +276,6 @@ ev_document_misc_invert_surface (cairo_surface_t *surface) {
 	cairo_set_source_rgb (cr, 1., 1., 1.);
 	cairo_paint(cr);
 	cairo_destroy (cr);
-#else
-	guchar *data;
-	gint    rowstride;
-	gint    width, height;
-	gint    x, y;
-
-	data = cairo_image_surface_get_data (surface);
-	rowstride = cairo_image_surface_get_stride (surface);
-	width = cairo_image_surface_get_width (surface);
-	height = cairo_image_surface_get_height (surface);
-
-	for (y = 0; y < height; y++) {
-		guchar *p = data + y * rowstride;
-
-		for (x = 0; x < width; x++) {
-			p[0] = 255 - p[0];
-			p[1] = 255 - p[1];
-			p[2] = 255 - p[2];
-			p += 4;
-		}
-	}
-
-	cairo_surface_mark_dirty (surface);
-#endif
 }
 
 void
